provider

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2026 License: AGPL-3.0 Imports: 7 Imported by: 0

Documentation

Overview

Package provider package provider provides the NetBird Pulumi provider implementation.

Index

Constants

const (
	Name    string = "netbird"
	Version string = "0.5.0"
)

Change to const to disable semver Version management Change to var to enable semver Version management.

Variables

This section is empty.

Functions

func Provider

func Provider() p.Provider

Provider creates and returns a new Pulumi provider for managing NetBird resources.

Types

This section is empty.

Directories

Path Synopsis
cmd
pulumi-resource-netbird command
Package main is the entry point for the Pulumi NetBird provider.
Package main is the entry point for the Pulumi NetBird provider.
Package component provides composite components for the NetBird Pulumi provider.
Package component provides composite components for the NetBird Pulumi provider.
Package config provideds configuration and error handling for the NetBird Pulumi provider.
Package config provideds configuration and error handling for the NetBird Pulumi provider.
Package function provides the NetBird Pulumi provider functions (invokes / data sources).
Package function provides the NetBird Pulumi provider functions (invokes / data sources).
Package resource provides the NetBird resource types
Package resource provides the NetBird resource types

Jump to